@@ -16,7 +16,7 @@ module Liquid
         when IsTag
           if token =~ FullToken
 
-            # if we found the proper block delimitor just end parsing here and let the outer block
+            # if we found the proper block delimiter just end parsing here and let the outer block
             # proceed
             if block_delimiter == $1
               end_tag
@@ -43,8 +43,8 @@ module Liquid
         end
       end
 
-      # Make sure that its ok to end parsing in the current block.
-      # Effectively this method will throw and exception unless the current block is
+      # Make sure that it's ok to end parsing in the current block.
+      # Effectively this method will throw an exception unless the current block is
       # of type Document
       assert_missing_delimitation!
     end
@@ -90,20 +90,31 @@ module Liquid
 
     def render_all(list, context)
       output = []
+      context.resource_limits[:render_length_current] = 0
+      context.resource_limits[:render_score_current] += list.length
+
       list.each do |token|
         # Break out if we have any unhanded interrupts.
         break if context.has_interrupt?
 
         begin
           # If we get an Interrupt that means the block must stop processing. An
-          # Interrupt is any command that stops block execution such as {% break %} 
+          # Interrupt is any command that stops block execution such as {% break %}
           # or {% continue %}
           if token.is_a? Continue or token.is_a? Break
             context.push_interrupt(token.interrupt)
             break
           end
 
-          output << (token.respond_to?(:render) ? token.render(context) : token)
+          token_output = (token.respond_to?(:render) ? token.render(context) : token)
+          context.resource_limits[:render_length_current] += (token_output.respond_to?(:length) ? token_output.length : 1)
+          if context.resource_limits_reached?
+            context.resource_limits[:reached] = true
+            raise MemoryError.new("Memory limits exceeded")
+          end
+          output << token_output
+        rescue MemoryError => e
+          raise e
         rescue ::StandardError => e
           output << (context.handle_error(e))
         end
